==> glewlwyd_2.3.3.orig.tar.gz: glewlwyd-2.3.3/docs/screenshots/README.md <==
# Glewlwyd screenshots

Screenshots available

## Login page

### Simple login with password

![login-new-user](login-new-user.png)

### Login without password

![login-nopassword](login-nopassword.png)

![login-admin-example](login-admin-example.png)

### Grant client access to scopes for the user

![login-grant](login-grant.png)

### Multiple session selector

![login-multiple-session](login-multiple-session.png)

### Logged in

![logged-in](logged-in.png)

## Admin page

### User list

![user-list](user-list.png)

### Client list

![mod-client-list](mod-client-list.png)

### Scope list

![scope-list](scope-list.png)

### Scope add

![scope-add](scope-add.png)

### List of user modules instanciated

![mod-user-list](mod-user-list.png)

### User database backend module configuration

![mod-user-database](mod-user-database.png)

### User HTTP backend module configuration

![mod-user-http](mod-user-http.png)

### User LDAP backend module configuration

![mod-user-ldap](mod-user-ldap.png)

### Client LDAP backend module configuration

![mod-client-ldap](mod-client-ldap.png)

### Scheme list

![mod-scheme-list](mod-scheme-list.png)

### OTP E-mail scheme configuration

![scheme-email](scheme-email.png)

### OATH HOTP/TOTP scheme configuration

![scheme-otp](scheme-otp.png)

### Webauthn scheme configuration

![scheme-webauthn](scheme-webauthn.png)

## Profile page

### User profile data editor

![profile-data](profile-data.png)

### User profile change password

![profile-password](profile-password.png)

### User profile session and tokens manager

![profile-session](profile-session.png)

### User profile OTP configuration

![profile-otp](profile-otp.png)

### User profile Webauthn configuration

![profile-webauthn](profile-webauthn.png)

### User profile TLS certificate configuration

![profile-certificate](profile-certificate.png)

### List of plugins instanciated

![plugin-list](plugin-list.png)

### OAuth2 plugin configuration

![plugin-oauth2](plugin-oauth2.png)

### OIDC plugin configuration

![plugin-oidc](plugin-oidc.png)

==> glewlwyd_2.5.2.orig.tar.gz: glewlwyd-2.5.2/docs/screenshots/README.md <==
# Glewlwyd screenshots

Screenshots available

## Login page

### Simple login with password

![login-new-user](login-new-user.png)

### Login without password

![login-nopassword](login-nopassword.png)

![login-admin-example](login-admin-example.png)

### Grant client access to scopes for the user

![login-grant](login-grant.png)

### Grant client access to scopes and Rich Authorization Requests for the user

![login-rar-grant](login-rar-grant.png)

### Multiple session selector

![login-multiple-session](login-multiple-session.png)

### Logged in

![logged-in](logged-in.png)

## Admin page

### User list

![user-list](user-list.png)

### Client list

![mod-client-list](mod-client-list.png)

### Scope list

![scope-list](scope-list.png)

### Scope add

![scope-add](scope-add.png)

### List of user modules instanciated

![mod-user-list](mod-user-list.png)

### User database backend module configuration

![mod-user-database](mod-user-database.png)

### User HTTP backend module configuration

![mod-user-http](mod-user-http.png)

### User LDAP backend module configuration

![mod-user-ldap](mod-user-ldap.png)

### Client LDAP backend module configuration

![mod-client-ldap](mod-client-ldap.png)

### Scheme list

![mod-scheme-list](mod-scheme-list.png)

### OTP E-mail scheme configuration

![scheme-email](scheme-email.png)

### OATH HOTP/TOTP scheme configuration

![scheme-otp](scheme-otp.png)

### Webauthn scheme configuration

![scheme-webauthn](scheme-webauthn.png)

## Profile page

### User profile data editor

![profile-data](profile-data.png)

### User profile change password

![profile-password](profile-password.png)

### User profile session and tokens manager

![profile-session](profile-session.png)

### User profile OTP configuration

![profile-otp](profile-otp.png)

### User profile Webauthn configuration

![profile-webauthn](profile-webauthn.png)

### User profile TLS certificate configuration

![profile-certificate](profile-certificate.png)

### List of plugins instanciated

![plugin-list](plugin-list.png)

### OAuth2 plugin configuration

![plugin-oauth2](plugin-oauth2.png)

### OIDC plugin configuration

![plugin-oidc](plugin-oidc.png)

### OIDC plugin configuration for OAuth 2.0 Rich Authorization Requests

![plugin-oidc-rar](plugin-oidc-rar.png)

### List of API keys created

![api-key-list](api-key-list.png)

### Create a new API key

![api-key-add](api-key-add.png)
